local FishWarden = FishWarden_79a6ca19_6666_4759_9b8f_a67708694e5b;

FishWarden.GUI.MiscFrame = CreateFrame("Frame", "FishWardenMiscPanel", UIParent);

local MainFrame = FishWarden.GUI.MainFrame;
local MiscFrame = FishWarden.GUI.MiscFrame;

function MiscFrame:DoInit()
    local checkwidth = 26;

    MiscFrame.name = MISCELLANEOUS;
    MiscFrame.parent = MainFrame.name;
    InterfaceOptions_AddCategory(MiscFrame);
    MiscFrame:SetScript("OnShow", MiscFrame.ShowHandler);
    
    MiscFrame.iddTitle = MiscFrame:CreateFontString("$parent_Title","ARTWORK","GameFontNormalLarge");
    MiscFrame.iddTitle:SetPoint("TOPLEFT", MiscFrame, "TOPLEFT", 13, -13);
    MiscFrame.iddTitle:SetText(MISCELLANEOUS);
    MiscFrame.iddTitle:SetJustifyH("CENTER");

    local lastanchor = MiscFrame.iddTitle;
    MiscFrame.Buttons = {};
    for i, v in ipairs(FishWarden.OtherFilters) do
        assert(v.name and v.display, "FishWarden.OtherFilters is corrupt. A filter is missing the name and/or display values.")
        MiscFrame.Buttons[v.name] = MiscFrame:AddCheck(v.display, "$parent_Btn" .. v.name, v.name,
            lastanchor, checkwidth);
        lastanchor = MiscFrame.Buttons[v.name];
    end

    if (MiscFrame.Buttons.FilterMiscPrice) then
        MiscFrame.iddPriceVal = CreateFrame("Frame", "$parent_PriceVal", MiscFrame, "MoneyInputFrameTemplate");
        MiscFrame.iddPriceVal:SetHeight(20);
        MiscFrame.iddPriceVal:SetPoint("LEFT", MiscFrame.Buttons.FilterMiscPrice.iddText, "RIGHT", 5, 0);
        MiscFrame.iddPriceVal:SetPoint("TOP", MiscFrame.Buttons.FilterMiscPrice, "TOP", 0, (20-checkwidth)/2);
        MoneyInputFrame_SetCopper(MiscFrame.iddPriceVal, FishWarden.Vars.FilterMiscPriceVal);
        MoneyInputFrame_SetOnValueChangedFunc(MiscFrame.iddPriceVal, MiscFrame.OnChangePriceVal);
    end

    if (MiscFrame.Buttons.FilterMiscItemLevel) then
        MiscFrame.iddMinItemLevel = CreateFrame("EditBox", "$parent_MinItemLevel", MiscFrame);
        MiscFrame.iddMinItemLevel:SetHeight(20);
        MiscFrame.iddMinItemLevel:SetWidth(30);
        MiscFrame.iddMinItemLevel:SetPoint("LEFT", MiscFrame.Buttons.FilterMiscItemLevel.iddText, "RIGHT", 5, 0);
        MiscFrame.iddMinItemLevel:SetPoint("TOP", MiscFrame.Buttons.FilterMiscItemLevel, "TOP", 0, (20-checkwidth)/2);
        MiscFrame.iddMinItemLevel:SetAutoFocus(false);
        MiscFrame.iddMinItemLevel:SetNumeric(true);
        MiscFrame.iddMinItemLevel:SetMaxLetters(3);
        MiscFrame.iddMinItemLevel:SetFontObject("ChatFontNormal");
        MiscFrame.iddMinItemLevel:SetScript("OnEscapePressed", EditBox_ClearFocus);
        MiscFrame.iddMinItemLevel:SetScript("OnEditFocusLost", EditBox_ClearHighlight);
        MiscFrame.iddMinItemLevel:SetScript("OnEditFocusGained", EditBox_HighlightText);
        MiscFrame.iddMinItemLevel:SetScript("OnTextChanged", MiscFrame.OnChangeMinItemLevel);

        local temp = MiscFrame.iddMinItemLevel:CreateTexture("$parent_Left", "BACKGROUND");
        temp:SetTexture("Interface\\Common\\Common-Input-Border");
        temp:SetWidth(8);
        temp:SetHeight(20);
        temp:SetPoint("TOPLEFT", MiscFrame.iddMinItemLevel, "TOPLEFT", -5, 0);
        temp:SetTexCoord(0, 0.0625, 0, 0.625);

        temp = MiscFrame.iddMinItemLevel:CreateTexture("$parent_Right", "BACKGROUND");
        temp:SetTexture("Interface\\Common\\Common-Input-Border");
        temp:SetWidth(8);
        temp:SetHeight(20);
        temp:SetPoint("RIGHT", MiscFrame.iddMinItemLevel, "RIGHT");
        temp:SetTexCoord(0.9375, 1, 0, 0.625);

        temp = MiscFrame.iddMinItemLevel:CreateTexture("$parent_Middle", "BACKGROUND");
        temp:SetTexture("Interface\\Common\\Common-Input-Border");
        temp:SetWidth(10);
        temp:SetHeight(20);
        temp:SetPoint("LEFT", "$parent_Left", "RIGHT");
        temp:SetPoint("Right", "$parent_Right", "LEFT");
        temp:SetTexCoord(0.0625, 0.9375, 0, 0.625);
    end
end

function MiscFrame:AddCheck(text, name, filter, anchor, width)
    local btnFrame = CreateFrame("CheckButton", name, MiscFrame, "UICheckButtonTemplate");
    btnFrame.FilterName = filter;
    btnFrame:SetWidth(width);
    btnFrame:SetHeight(width);
    btnFrame:SetPoint("TOPLEFT", anchor, "BOTTOMLEFT", 0, 0);
    btnFrame:SetScript("OnClick", MiscFrame.OnClickFilter);

    btnFrame.iddText = getglobal(btnFrame:GetName() .. 'Text');
    btnFrame.iddText:SetText(text);
    btnFrame.iddText:SetTextColor(1, 1, 1);
    btnFrame.iddText:SetJustifyH("LEFT");

    btnFrame.iddClicker = CreateFrame("Button", name .. "Clicker", btnFrame);
    btnFrame.iddClicker.FilterName = filter;
    btnFrame.iddClicker:SetAllPoints(btnFrame.iddText);
    btnFrame.iddClicker:SetScript("OnClick", MiscFrame.OnClickFilter);
    btnFrame.iddClicker:SetScript("OnEnter", MainFrame.OnEnterClicker);
    btnFrame.iddClicker:SetScript("OnLeave", MainFrame.OnLeaveClicker);
    return btnFrame;
end

function MiscFrame:refresh()
    for k, v in pairs(MiscFrame.Buttons) do
        v:SetChecked(FishWarden.Vars[k]);
    end
end

function MiscFrame:ShowHandler(...)
    local maxwidth = MiscFrame:GetWidth();
    if (maxwidth == 0) then maxwidth = 413; end

    MiscFrame.iddTitle:SetWidth(maxwidth - 26);

    for k, v in pairs(MiscFrame.Buttons) do
        if (k == "FilterMiscPrice") then
            v.iddText:SetWidth( min(v.iddText:GetStringWidth(), maxwidth - v:GetWidth() - MiscFrame.iddPriceVal:GetWidth() - 26 - 5) );
            MoneyInputFrame_ResetMoney(MiscFrame.iddPriceVal);
            MoneyInputFrame_SetCopper(MiscFrame.iddPriceVal, FishWarden.Vars.FilterMiscPriceVal);
        elseif (k == "FilterMiscItemLevel") then
            v.iddText:SetWidth( min(v.iddText:GetStringWidth(), maxwidth - v:GetWidth() - MiscFrame.iddMinItemLevel:GetWidth() - 26 - 5) );
            MiscFrame.iddMinItemLevel:SetText(FishWarden.Vars.FilterMiscMinItemLevel or 0);
        else
            v.iddText:SetWidth( min(v.iddText:GetStringWidth(), maxwidth - v:GetWidth() - 26) );
        end
    end
end

function MiscFrame:OnClickFilter(button)
    if (button == "LeftButton" and self.FilterName) then
        FishWarden.Vars[self.FilterName] = not FishWarden.Vars[self.FilterName];
        FishWarden.OtherFish.Valid = false;
        MiscFrame:refresh();
    end
end

function MiscFrame.OnChangePriceVal()
    local amount = MoneyInputFrame_GetCopper(MiscFrame.iddPriceVal);
    if (not amount) then amount = 0; end
    FishWarden.Vars.FilterMiscPriceVal = amount;
end

function MiscFrame:OnChangeMinItemLevel(UI)
    if (UI) then
        FishWarden.Vars.FilterMiscMinItemLevel = self:GetNumber();
    end
end

